// Sample data for papers
const papers = [
  {
    title: "Mitochondrial DNA and Human Evolution",
    author: "Cann, Stoneking & Wilson",
    year: 1987,
    category: "evolution",
    pdf: "/papers/mitochondrial-dna-human-evolution.pdf"
  },
  {
    title: "The Role of Mitochondria in Apoptosis",
    author: "Green & Reed",
    year: 1998,
    category: "biochemistry",
    pdf: "/papers/mitochondria-apoptosis.pdf"
  },
  // Add more papers here...
];

// DOM Elements
const paperContainer = document.getElementById('paperContainer');
const searchInput = document.getElementById('searchInput');
const searchButton = document.getElementById('searchButton');
const categoryCards = document.querySelectorAll('.category-card');

// Display papers
function displayPapers(filteredPapers) {
  paperContainer.innerHTML = filteredPapers.map(paper => `
    <div class="paper-card">
      <h3>${paper.title}</h3>
      <p>${paper.author} (${paper.year})</p>
      <a href="${paper.pdf}" class="download-link" download>Download PDF</a>
    </div>
  `).join('');
}

// Initial display
displayPapers(papers);

// Search functionality
searchButton.addEventListener('click', () => {
  const searchTerm = searchInput.value.toLowerCase();
  const filteredPapers = papers.filter(paper => 
    paper.title.toLowerCase().includes(searchTerm) ||
    paper.author.toLowerCase().includes(searchTerm)
  );
  displayPapers(filteredPapers);
});

// Category filtering
categoryCards.forEach(card => {
  card.addEventListener('click', () => {
    const category = card.dataset.category;
    const filteredPapers = papers.filter(paper => 
      paper.category === category
    );
    displayPapers(filteredPapers);
  });
});
